@@ -56,7 +56,7 @@ class Collect:
                 loop.run_in_executor(
                     executor, functools.partial(self.parallel_docs, doc, cdclass),
                 )
-                for doc, cdclass in track(
+                for cdclass, doc in track(
                     keys, description=f"Getting keys in {settings.base}"
                 )
             ]
